import cx from 'classnames';
import PropTypes from 'prop-types';
import SuiLazyLoadImage from '@s-ui/react-image-lazy-load';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var ensureFunction = function ensureFunction(func) {
  return func instanceof Function ? func : function () {};
};

/**
 * Render a simple sui-image-lazy-load component.
 * @param image {Object} src, alt and onClick callback configuration of the image to display.
 */
var renderSuiLazyloadImage = function renderSuiLazyloadImage(image) {
  return /*#__PURE__*/_jsx(SuiLazyLoadImage, {
    debounce: false,
    offsetVertical: 100,
    src: image.src,
    alt: image.alt,
    showSpinner: true,
    aspectRatio: "1:1"
  });
};

/**
 * Creates a simple list item containing a regular image with the configuration provided.
 * @param image {Object} src, alt and onClick callback configuration of the image to display.
 * @param index {Number} Order index of the li element to create.
 */
var renderImageItem = function renderImageItem(image, index) {
  return image && /*#__PURE__*/_jsx("li", {
    className: "sui-ListImage-item",
    onClick: ensureFunction(image.onClick),
    children: renderSuiLazyloadImage(image)
  }, index);
};

/**
 * Creates an special list item, which has a regular image and an additional cover box over it with customisable message
 * and onClick event callback.
 * The HTML structure of this list-item is slightly different that the regular Image Item.
 * @param image {Object} src, alt and onClick callback configuration of the image to display.
 * @param index {Number} Order index of the li element to create.
 * @param moreItemsBox {Object} Text and onClick callback configuration for the list-item to be created.
 */
var renderImageWithMoreItemsBox = function renderImageWithMoreItemsBox(image, index, moreItemsBox) {
  return image && /*#__PURE__*/_jsx("li", {
    className: "sui-ListImage-item",
    onClick: ensureFunction(moreItemsBox.onClick),
    children: /*#__PURE__*/_jsxs("div", {
      className: "sui-ListImage-lastItemContainer",
      children: [renderSuiLazyloadImage(image), /*#__PURE__*/_jsx("div", {
        className: "sui-ListImage-moreItemsBox",
        children: moreItemsBox.label && /*#__PURE__*/_jsx("span", {
          className: "sui-ListImage-moreItemsBoxLabel",
          children: moreItemsBox.label
        })
      })]
    })
  }, index);
};
var ListImage = function ListImage(_ref) {
  var className = _ref.className,
    images = _ref.images,
    maxItems = _ref.maxItems,
    moreItemsBox = _ref.moreItemsBox;
  return /*#__PURE__*/_jsxs("ul", {
    className: cx('sui-ListImage', className),
    children: [images.slice(0, maxItems - 1).map(renderImageItem), images.length > maxItems && !!moreItemsBox ? renderImageWithMoreItemsBox(images[maxItems - 1], maxItems - 1, moreItemsBox) : renderImageItem(images[maxItems - 1], maxItems - 1)]
  });
};
ListImage.displayName = 'ListImage';
ListImage.defaultProps = {
  maxItems: 6
};
export default ListImage;